@@ -17,10 +17,12 @@ class ContactFormCategory(TranslatableModel):
         max_length=256,
         verbose_name=_('Slug'),
     )
-
     translations = TranslatedFields(
-        name=models.CharField(max_length=256),
+        name=models.CharField(
+            max_length=256,
+            verbose_name=_('Name'),
+        )
     )
 
     def __unicode__(self):
-        return self.lazy_translation_getter('name', 'Untranslated')
+        return self.lazy_translation_getter('name', self.slug)
