@@ -6,8 +6,8 @@ from ..models import ContactFormCategory
 
 
 class ContactFormCategoryFactory(HvadFactoryMixin, factory.DjangoModelFactory):
-    """The Factory for a ``ContactFormCategory``."""
+    """The Factory for the ``ContactFormCategory`` model."""
     FACTORY_FOR = ContactFormCategory
 
-    language_code = 'en'
-    name = factory.Sequence(lambda x: 'Category {}'.format(x))
+    slug = factory.Sequence(lambda n: 'slug_{0}'.format(n))
+    name = factory.Sequence(lambda n: 'name {0}'.format(n))
