@@ -12,5 +12,3 @@ class ContactFormCategoryTestCase(TestCase):
         obj = ContactFormCategoryFactory()
         self.assertTrue(obj.pk, msg=(
             'Should be able to instantiate and save the model.'))
-        self.assertTrue(obj.get_translation(), msg=(
-            'The factory should also create a translation'))
