@@ -1,6 +1,6 @@
 """URLs for bitmazk-contact-form application."""
 
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, url
 
 from contact_form.views import ContactFormView
 
